Binary operations
*****************

.. currentmodule:: numpy

Elementwise bit operations
--------------------------
.. autosummary::
   :toctree: generated/

   bitwise_and
   bitwise_or
   bitwise_xor
   invert
   left_shift
   right_shift

Bit packing
-----------
.. autosummary::
   :toctree: generated/

   packbits
   unpackbits

Output formatting
-----------------
.. autosummary::
   :toctree: generated/

   binary_repr
